# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Perl-Critic-More
Version:	1.003
Release:	27.%{__distinit}%{__distvers}
Summary:	Supplemental policies for Perl::Critic
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Perl-Critic-More
Source0:	https://cpan.metacpan.org/modules/by-module/Perl/Perl-Critic-More-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(English)
BuildRequires:	perl(List::MoreUtils)
BuildRequires:	perl(Perl::Critic) >= 1.098
BuildRequires:	perl(Perl::Critic::Policy)
BuildRequires:	perl(Perl::Critic::Utils)
BuildRequires:	perl(Perl::MinimumVersion) >= 0.14
BuildRequires:	perl(Readonly) >= 1.03
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Perl::Critic::Config)
BuildRequires:	perl(Perl::Critic::TestUtils)
BuildRequires:	perl(Perl::Critic::Violation)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(utf8)
# Extra Tests
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Perl::Critic::PolicyFactory)
BuildRequires:	perl(PPI::Document)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Portability::Files)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Perl::Critic) >= 1.098
Requires:	perl(Perl::MinimumVersion) >= 0.14

%description
This is a collection of Perl::Critic policies that are not included in the
Perl::Critic core for a variety of reasons:

* Experimental
* Requires special dependencies
* Peripheral to Perl
* Special purpose

All of these policies have the theme more so they can be turned off as a group
via .perlcriticrc by adding this line:

  theme = not more

The special purpose ones may be part of the notrecommended theme. Avoid these
via:

  theme = not notrecommended

%prep
%setup -q -n Perl-Critic-More-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

# Shouldn't be installing TODO.pod
rm -v %{buildroot}%{perl_vendorlib}/Perl/Critic/TODO.pod
rm -v %{buildroot}%{_mandir}/man3/Perl::Critic::TODO.3*

%check
make test
# xt/author/40_criticize.t has multiple failures
AUTHOR_TESTS="$(echo $(find xt/ -name '*.t' -print | grep -Fvx xt/author/40_criticize.t))"
make test TEST_FILES="$AUTHOR_TESTS"

%files
%license LICENSE
%doc Changes README TODO.pod
%{perl_vendorlib}/Perl/
%{_mandir}/man3/Perl::Critic::More.3*
%{_mandir}/man3/Perl::Critic::Policy::CodeLayout::RequireASCII.3*
%{_mandir}/man3/Perl::Critic::Policy::Editor::RequireEmacsFileVariables.3*
%{_mandir}/man3/Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions.3*
%{_mandir}/man3/Perl::Critic::Policy::Modules::PerlMinimumVersion.3*
%{_mandir}/man3/Perl::Critic::Policy::Modules::RequirePerlVersion.3*
%{_mandir}/man3/Perl::Critic::Policy::ValuesAndExpressions::RequireConstantOnLeftSideOfEquality.3*
%{_mandir}/man3/Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings.3*

%changelog
* Mon Jul 10 2023 Paul Howarth <paul@city-fan.org> - 1.003-27
- Use SPDX-format license tag
- Drop support for building with rpm < 4.9
- Use %%license unconditionally

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.003-15
- Perl 5.30 rebuild

* Tue Apr 17 2018 Paul Howarth <paul@city-fan.org> - 1.003-11
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Perl < 5.8.8

* Tue Sep 20 2016 Paul Howarth <paul@city-fan.org> - 1.003-7
- Classify buildreqs by usage
- Simplify find command using -delete
- Don't install TODO.pod, ship it as %%doc instead

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 1.003-3
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Oct 29 2013 Paul Howarth <paul@city-fan.org> - 1.003-1
- Update to 1.003
  - Updated the postal address for FSF in the LICENSE (CPAN RT#80380)

* Tue Oct 29 2013 Paul Howarth <paul@city-fan.org> - 1.002-2
- Miscellanea::RequireRcsKeywords moved to Perl-Critic-Deprecated

* Sat Oct 26 2013 Paul Howarth <paul@city-fan.org> - 1.002-1
- Update to 1.002
  - ValuesAndExpressions::RequireConstantOnLeftSideOfEquality - In case you
    accidentally say "if ($foo = 42) {...}"
  - "use 5.006001" in Makefile.PL and Build.PL
- This release by THALJEF -> update source URL
- BR:/R: perl(Perl::MinimumVersion) ≥ 0.14

* Thu Jul 12 2012 Paul Howarth <paul@city-fan.org> - 1.000-6
- Miscellanea::RequireRcsKeywords moved here from the core Perl::Critic
  distribution (CPAN RT#69546)
- BR: perl(base), perl(Carp), perl(English), perl(ExtUtils::Manifest),
  perl(File::Spec), perl(List::MoreUtils), perl(Perl::Critic::Config),
  perl(Perl::Critic::Policy), perl(Perl::Critic::PolicyFactory),
  perl(Perl::Critic::TestUtils), perl(Perl::Critic::Utils) and
  perl(PPI::Document)

* Thu Mar  1 2012 Paul Howarth <paul@city-fan.org> - 1.000-4
- Hack t/20_policies_codelayout.t to get it to work with perl < 5.8.8
- Don't need to remove empty directories from buildroot

* Tue Oct 18 2011 Paul Howarth <paul@city-fan.org> - 1.000-3
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 1.000-2
- Rebuild for perl 5.14.1 in Rawhide
- Use DESTDIR rather than PERL_INSTALL_ROOT
- Nobody else likes macros for commands

* Fri Mar 18 2011 Paul Howarth <paul@city-fan.org> - 1.000-1
- Initial RPM version
